@@ -1,4 +1,4 @@
-from rc.provider import gcloud, azure, digitalocean
+from rc.provider import gcloud, azure, digitalocean, aws
 from rc.machine import Machine
 from rc.util import run, RunException, RunResult, running, run_stream, handle_stream, \
     STDERR, STDOUT, EXIT, go, pmap, as_completed, print_stream, save_stream_to_file, \
